@@ -5,10 +5,7 @@ if [ "${GITHUB_ACTIONS_OS}" == "linux" ] ; then
     eval "$(dbus-launch --sh-syntax)" && \
     mkdir -p ~/.cache ~/.local/share/keyrings && \
     eval "$(printf '\n' | gnome-keyring-daemon --unlock)" && \
-    eval "$(printf '\n' | /usr/bin/gnome-keyring-daemon --start)" && \
-
-    cargo test --release --locked
-
-else
-    cargo test --release --locked
+    eval "$(printf '\n' | /usr/bin/gnome-keyring-daemon --start)"
 fi
+
+cargo test --release --locked
